==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/RepositoryCore/src/com/clustercontrol/repository/action/GetScopeProperty.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.repository.action;

import java.rmi.AccessException;
import java.rmi.RemoteException;
import java.util.Locale;

import javax.ejb.FinderException;
import javax.naming.NamingException;

import org.eclipse.jface.dialogs.MessageDialog;

import com.clustercontrol.bean.Property;
import com.clustercontrol.repository.ejb.session.RepositoryController;
import com.clustercontrol.repository.util.EjbConnectionManager;
import com.clustercontrol.util.Messages;

/**
 * °륯饹Ǥ
 * 
 * @version 1.0.0
 * @since 1.0.0
 */
public class GetScopeProperty {

    /**
     * °֤ޤ
     * 
     * @param facilityId
     * @param property
     * @return °
     */
    public Property getProperty(String facilityId, int mode) {
        RepositoryController repository = EjbConnectionManager
                .getConnectionManager().getRepositoryController();

        Property property = null;
        try {
            property = repository.getScopeProperty(facilityId, mode, Locale
                    .getDefault());
        } catch (RemoteException e) {
			if(e instanceof AccessException){
				// ʤξ硢顼ɽ
	            MessageDialog.openInformation(null, Messages.getString("message"),
	                    Messages.getString("message.accesscontrol.16"));
			}
        } catch (FinderException e) {
        } catch (NamingException e) {
        }
        return property;
    }
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/RepositoryCore/src/com/clustercontrol/repository/action/GetScopeProperty.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.repository.action;

import java.rmi.AccessException;
import java.rmi.RemoteException;
import java.util.Locale;

import javax.ejb.FinderException;
import javax.naming.NamingException;

import org.eclipse.jface.dialogs.MessageDialog;

import com.clustercontrol.bean.Property;
import com.clustercontrol.repository.ejb.session.RepositoryController;
import com.clustercontrol.repository.util.EjbConnectionManager;
import com.clustercontrol.util.Messages;

/**
 * スコープ属性情報を取得するクラスです。
 * 
 * @version 1.0.0
 * @since 1.0.0
 */
public class GetScopeProperty {

    /**
     * スコープ属性情報を返します。
     * 
     * @param facilityId
     * @param property
     * @return スコープ属性情報
     */
    public Property getProperty(String facilityId, int mode) {
        RepositoryController repository = EjbConnectionManager
                .getConnectionManager().getRepositoryController();

        Property property = null;
        try {
            property = repository.getScopeProperty(facilityId, mode, Locale
                    .getDefault());
        } catch (RemoteException e) {
			if(e instanceof AccessException){
				// アクセス権なしの場合、エラーダイアログを表示する
	            MessageDialog.openInformation(null, Messages.getString("message"),
	                    Messages.getString("message.accesscontrol.16"));
			}
        } catch (FinderException e) {
        } catch (NamingException e) {
        }
        return property;
    }
}
